@@ -1,13 +1,14 @@
 #/bin/env python
 #coding:UTF-8
 '''一个用来递归打印列表中所有元素的函数。'''
-def print_lol(the_list, level=0):
+def print_lol(the_list, indent=false, level=0):
 	for each_item in the_list:
 		if isinstance(each_item, list):
-			print_lol(each_item, level+1)
+			print_lol(each_item, indent, level+1)
 		else:
-			for tab_stop in range(level):
-				print("\t"),
+			if indent:
+				for tab_stop in range(level):
+					print("\t"),
 			print(each_item)
 
 if __name__ == '__main__':
